==> omnicompiler-0.9.tar.bz2: omnicompiler-0.9/docs/RELEASE_NOTES.md <==
Omni Compiler Software RELEASE NOTES

# ver. 0.9.0      2014/11/14
* Support post/wait operations for the K computer and FX10.
* Support the XMP_NODE_SIZEn environment variable to specify an extent of a non-primary
  node array at runtime.
* Support elemental functions in array constructs.
* Support way to call MPI programs from/to XMP programs.
* Support xmp_matmul and xmp_transpose intrinsic functions.
* Fixed lots of bugs.

# ver. 0.8.0      2014/04/25
* Support Coarray communication for the K computer and FX10.
* Support the gblock distribution
* Support the template_fix directive
* Support the array directive (with some restrictions)
* Support clauses of the reflect directive in XMP/C
* Support the xmp_malloc built-in function in XMP/C
* Support clauses of the bcast, barrier, reduction directives in XMP/F
* Support fully the node directive in XMP/F
* Fixed lots of bugs.

# ver. 0.7.0      2013/11/20
* Improve shadow/reflect directive.
* Fixed some bugs.

# ver. 0.6.1      2013/03/27
* Supports stride Coarray function. (only by using GASNet)
* Supports coarray function on the K computer and FX10.

# ver. 0.6.0      2012/11/12
* Initial release of XcalableMP Fortran compiler.
* (Coarray feature will be added soon)

# ver. 0.5.4      2011/11/11
* Supports block-cyclic distribution in distribute directive

# ver. 0.5.3      2011/04/08
* Fixed problems with rewriting expressions

# ver. 0.5.2      2011/03/11
* Fixed bugs in runtime

# ver. 0.5.1      2011/03/09
* gmove between aligned array and duplicated array using array section is suppoted.

--
    #pragma xmp align a[i] with t(i)

    #pragma xmp gmove
    local[:] = a[:];
--

* full shadow reflect is implemented.

# ver. 0.5.0	2010/11/13
* This is the first release of Omni Compiler.

==> omnicompiler-0.9.1.tar.bz2: omnicompiler-0.9.1/docs/RELEASE_NOTES.md <==
Omni Compiler Software RELEASE NOTES

# ver. 0.9.1      2015/04/21
* Support major features of Coarray Fortran 1.0.
* Refactoring xmpcc command.
* Refactoring build system (without requiring ant).
* Support stride coarray on the K computer and FX10.
* Support the xmp_malloc function for multidimensional global arrays.
* Support the async clause on the bcast and the reduction directives.
* Support the pack/unpack, gather/scatter, and sort_up/sort_down intrinsic procedures.
* Fixed lots of bugs.

# ver. 0.9.0      2014/11/14
* Support post/wait operations for the K computer and FX10.
* Support the XMP_NODE_SIZEn environment variable to specify an extent of a non-primary
  node array at runtime.
* Support elemental functions in array constructs.
* Support way to call MPI programs from/to XMP programs.
* Support xmp_matmul and xmp_transpose intrinsic functions.
* Fixed lots of bugs.

# ver. 0.8.0      2014/04/25
* Support Coarray communication for the K computer and FX10.
* Support the gblock distribution
* Support the template_fix directive
* Support the array directive (with some restrictions)
* Support clauses of the reflect directive in XMP/C
* Support the xmp_malloc built-in function in XMP/C
* Support clauses of the bcast, barrier, reduction directives in XMP/F
* Support fully the node directive in XMP/F
* Fixed lots of bugs.

# ver. 0.7.0      2013/11/20
* Improve shadow/reflect directive.
* Fixed some bugs.

# ver. 0.6.1      2013/03/27
* Supports stride Coarray function. (only by using GASNet)
* Supports coarray function on the K computer and FX10.

# ver. 0.6.0      2012/11/12
* Initial release of XcalableMP Fortran compiler.
* (Coarray feature will be added soon)

# ver. 0.5.4      2011/11/11
* Supports block-cyclic distribution in distribute directive

# ver. 0.5.3      2011/04/08
* Fixed problems with rewriting expressions

# ver. 0.5.2      2011/03/11
* Fixed bugs in runtime

# ver. 0.5.1      2011/03/09
* gmove between aligned array and duplicated array using array section is suppoted.

--
    #pragma xmp align a[i] with t(i)

    #pragma xmp gmove
    local[:] = a[:];
--

* full shadow reflect is implemented.

# ver. 0.5.0	2010/11/13
* This is the first release of Omni Compiler.
